aboutsummaryrefslogtreecommitdiffhomepage
path: root/include/gpu/GrGpuResource.h
diff options
context:
space:
mode:
authorGravatar bsalomon <bsalomon@google.com>2015-02-13 14:20:05 -0800
committerGravatar Commit bot <commit-bot@chromium.org>2015-02-13 14:20:05 -0800
commit3582d3ee9fffdec715f5e4949a241ab08e6271ec (patch)
treeeab9709bbe8c4d00cd11fb987654cfb9e51acc65 /include/gpu/GrGpuResource.h
parent4ccce7ea618fd9557a6d5cfa29c1fd6b015c7580 (diff)
Split out methods in GrGpuResource::CacheAccess that can be called outside of the cache.
Diffstat (limited to 'include/gpu/GrGpuResource.h')
-rw-r--r--include/gpu/GrGpuResource.h9
1 files changed, 8 insertions, 1 deletions
diff --git a/include/gpu/GrGpuResource.h b/include/gpu/GrGpuResource.h
index 8e983d89c5..baffd9ec83 100644
--- a/include/gpu/GrGpuResource.h
+++ b/include/gpu/GrGpuResource.h
@@ -207,13 +207,20 @@ public:
const SkData* getCustomData() const { return fData.get(); }
/**
* Internal-only helper class used for cache manipulations of the reosurce.
*/
class CacheAccess;
inline CacheAccess cacheAccess();
inline const CacheAccess cacheAccess() const;
/**
+ * Internal-only helper class used for manipulations of the resource by internal code.
+ */
+ class ResourcePriv;
+ inline ResourcePriv resourcePriv();
+ inline const ResourcePriv resourcePriv() const;
+
+ /**
* Removes references to objects in the underlying 3D API without freeing them.
* Called by CacheAccess.
* In general this method should not be called outside of skia. It was
@@ -207,13 +207,20 @@ public:
const SkData* getCustomData() const { return fData.get(); }
/**
- * Internal-only helper class used for cache manipulations of the reosurce.
+ * Internal-only helper class used for manipulations of the resource by the cache.
*/
class CacheAccess;